# Bladed Results API Version 2

The Bladed Results API v2 is an easy, fast, and robust way to access Bladed results using Python.

It provides features for:

- Searching a directory tree for Bladed runs.
- Returning variables and data.
- Reporting run, group, and variable metadata.
- Writing user-defined output groups.

The API is able to read results from any Bladed version.

The API depends on the [`numpy`](https://numpy.org) package, version 2.0.2 or later.

> Currently only Windows is supported.
>
> Bladed Results API v2 replaces Results API 1.x which has been discontinued.

## Pre-requisites

- Requires a 32- or 64-bit Windows installation of any Python version from **3.9** to **3.14** inclusive.

> 64-bit Python is recommended.

- The Results API has been tested on Windows 11.

## Quick Start

```shell
pip install --upgrade dnv-bladed-results
```

```python
from dnv_bladed_results import ResultsApi

run = ResultsApi.get_run("c:/Data/5MW", "powprod")

var_1d = run.get_variable_1d("rotating hub mx")
print(var_1d.get_data())

var_2d = run.get_variable_2d("blade 1 mx (principal elastic axes)")
# Print loads 28.5m from root:
print(var_2d.get_data_at_value(28.5))
# Equivalent using blade station index:
print(var_2d.get_data_at_index(3))
```

## Learn More

Visit the [`Knowledge Centre`](https://mysoftware.dnv.com/download/public/bladed/site/documentation/Workflow/analysingOutputs/ResultsAPI.html) for more information about the Results API v2.
